<?php

namespace Neutrino\Ion3Core\Database\Factories;

use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\Factory;
use Neutrino\Ion3Core\Enums\RESOLookupOpenHouseType;

class OpenHouseFactory extends Factory
{
    protected $model = 'App\Ion3\Models\OpenHouse';

    /**
     * Define the model's default state.
     *
     * @return array<string, mixed>
     */
    public function definition(): array
    {
        $today = Carbon::today();
        $nextSaturday = $today->copy()->next(Carbon::SATURDAY);
        $nextSunday = $today->copy()->next(Carbon::SUNDAY);

        $startTimes = ['09:00:00', '09:30:00', '10:00:00', '10:30:00', '11:00:00', '11:30:00', '12:00:00'];
        $endTimes = ['12:30:00', '13:00:00', '13:30:00', '14:00:00', '14:30:00', '15:00:00', '15:30:00'];

        return [
            'listing_id' => null,
            'ion_source' => 'Manual',
            'originating_system_name' => 'Ion3',
            'open_house_type' => $this->faker->randomElement(RESOLookupOpenHouseType::class),
            'open_house_date' => $this->faker->randomElement([$nextSaturday, $nextSunday]),
            'open_house_start_time' => $this->faker->randomElement($startTimes),
            'open_house_end_time' => $this->faker->randomElement($endTimes),
            'open_house_remarks' => $this->faker->paragraph(),
            'open_house_key' => $this->faker->regexify('[A-Z][0-9]{7}'),
            'modification_timestamp' => $this->faker->dateTimeThisMonth(),
        ];
    }
}
