<?php

namespace Neutrino\Ion3Core\Database\Factories;

use App\Models\User;
use Illuminate\Database\Eloquent\Factories\Factory;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

/**
 * @extends \Illuminate\Database\Eloquent\Factories\Factory<\App\Models\User>
 */
class UserFactory extends Factory
{
    protected $model = User::class;
    protected static ?string $password;

    /**
     * Define the model's default state.
     *
     * @return array<string, mixed>
     */
    public function definition(): array
    {
        $first_name = fake()->firstName();
        $last_name = fake()->lastName();
        $email = fake()->unique()->safeEmail();
        $username = explode('@', $email)[0];
        return [
            'ion_source' => 'Manual',
            'first_name' => $first_name,
            'last_name' => $last_name,
            'username' => $username,
            'active' => true,
            'title' => fake()->jobTitle(),
            'slug' => Str::slug("{$first_name} {$last_name}"),
            'display_name' => "{$first_name} {$last_name}",
            'familiar_name' => $first_name,
            'phone_mobile' => fake()->phoneNumber(),
            'phone_office' => fake()->phoneNumber(),
            //'photo_url' => fake()->imageUrl(), - skipping so default image shows instead
            'show_online' => true,

            'email' => $email,
            'email_verified_at' => now(),
            'password' => static::$password ??= Hash::make('password'),
            'remember_token' => Str::random(10),
        ];
    }

    /**
     * Indicate that the model's email address should be unverified.
     */
    public function unverified(): static
    {
        return $this->state(fn (array $attributes) => [
            'email_verified_at' => null,
        ]);
    }
}
