<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        $Enums = [];

        // Matches RESOLookupPropertyType
        $Enums['PropertyType'] = [
            "Business Opportunity",
            "Commercial Lease",
            "Commercial Sale",
            "Farm",
            "Land",
            "Manufactured In Park",
            "Residential",
            "Residential Income",
            "Residential Lease",
        ];

        // Matches RESOLookupPropertySubType
        $Enums['PropertySubType'] = [
            "Agriculture",
            "Apartment",
            "Boat Slip",
            "Business",
            "Cabin",
            "Condominium",
            "Co-Ownership",
            "Deeded Parking",
            "Duplex",
            "Farm",
            "Hotel/Motel",
            "Industrial",
            "Manufactured Home",
            "Manufactured On Land",
            "Mixed Use",
            "Mobile Home",
            "Mobile Home Park",
            "Multi Family",
            "Office",
            "Own Your Own",
            "Quadruplex",
            "Ranch",
            "Retail",
            "Single Family Residence",
            "Stock Cooperative",
            "Tenancy in Common",
            "Timeshare",
            "Townhouse",
            "Triplex",
            "Unimproved Land",
            "Warehouse",
        ];

        // Matches RESOLookupStandardStatus
        $Enums['StandardStatus'] = [
            "Active",
            "Active Under Contract",
            "Canceled",
            "Closed",
            "Coming Soon",
            "Delete",
            "Expired",
            "Hold",
            "Incomplete",
            "Pending",
        ];

        // Matches IonLookupListingType
        $Enums['IonLookupListingType'] = [
            'Sale',
            'Lease',
            'Sale or Lease',
        ];

        Schema::create('listings', function (Blueprint $table) use ($Enums) {
            $table->comment('Listings: From MLS and other sources');
            $table->id();
            $table->string('ion_source', 16); // Our source ID - CWS, RESO, DASH, MANUAL, etc
            $table->enum('ion_listing_type', $Enums['IonLookupListingType'])->default('Sale');
            $table->string('originating_system_name', 100)->default(''); // MLS Name
            $table->string('list_aor', 36)->default(''); // "AOR" Number - Association of Realtors
            $table->string('listing_id', 36)->default(''); // "MLS" Number

            $table->string('unparsed_address', 128)->default('');
            $table->string('unit_number', 24)->default('');
            $table->string('city', 50)->default('');
            $table->string('state_or_province', 2)->default('');
            $table->string('postal_code', 10)->default('');
            $table->string('county_or_parish', 50)->default('');
            $table->string('country', 2)->default('US');
            $table->string('mls_area_major', 50)->default('');
            $table->string('mls_area_minor', 50)->default('');
            $table->string('subdivision_name', 50)->default('');
            $table->string('building_name', 50)->default('');
            $table->string('high_school_district', 50)->default('');

            $table->enum('property_type', array_merge($Enums['PropertyType'], ['']))->default('');
            $table->enum('property_sub_type', array_merge($Enums['PropertySubType'], ['']))->default('');
            $table->enum('standard_status', $Enums['StandardStatus'])->default('Delete');
            $table->integer('list_price')->default(0);
            $table->integer('original_list_price')->default(0);
            $table->integer('close_price')->default(0);
            $table->string('buyer_agency_compensation', 25)->default('');
            $table->smallInteger('bedrooms_total')->default(0);
            $table->smallInteger('bathrooms_full')->default(0);
            $table->smallInteger('bathrooms_half')->default(0);
            $table->smallInteger('bathrooms_one_quarter')->default(0);
            $table->smallInteger('bathrooms_three_quarter')->default(0);
            $table->integer('living_area')->default(0);
            $table->integer('lot_size_square_feet')->default(0);
            $table->double('lot_size_acres', 9, 2)->default(0);
            $table->smallInteger('year_built')->default(0);
            $table->string('parcel_number', 50)->default('');
            $table->string('attribution_contact', 80)->default('');
            $table->smallInteger('days_on_market')->default(0);
            $table->boolean('internet_entire_listing_display_yn')->default(0);
            $table->boolean('internet_address_display_yn')->default(0);

            $table->double('latitude', 14, 11)->nullable();
            $table->double('longitude', 14, 11)->nullable();

            $table->dateTimeTz('modification_timestamp')->default(now());
            $table->date('listing_contract_date')->default(now());
            $table->date('close_date')->nullable();
            $table->dateTimeTz('pending_timestamp')->nullable();

            $table->date('ion_days_on_market_date')->default(now());
            $table->bigInteger('ion_duplicate_of')->default(0);

            $table->softDeletesTz();
            $table->timestampsTz();

            $table->index('ion_source');
            $table->index('ion_listing_type');
            $table->index('originating_system_name');
            $table->index('list_aor');
            $table->index('listing_id');
            $table->index('unparsed_address');
            $table->index('city');
            $table->index('state_or_province');
            $table->index('postal_code');
            $table->index('property_type');
            $table->index('property_sub_type');
            $table->index('standard_status');
            $table->index('list_price');
            $table->index('bedrooms_total');
            $table->index('year_built');
            $table->index('modification_timestamp');
            $table->index('listing_contract_date');
            $table->index('close_date');
            $table->index('pending_timestamp');
            $table->index('ion_duplicate_of');
            $table->index(['latitude', 'longitude']);
            $table->index('deleted_at');
            $table->index('created_at');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('listings');
    }
};
