<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('company_locations', function (Blueprint $table) {
            $table->comment('Company Locations: Our companies\' locations, not from MLS or other sources');
            $table->id();
            $table->string('name', 64);
            $table->foreignId('company_id')->nullable()->constrained('companies');
            $table->foreignId('parent_id')->nullable()->constrained('company_locations');
            $table->string('photo_url', 255)->nullable();
            $table->string('address', 64)->nullable();
            $table->string('address2', 64)->nullable();
            $table->string('city', 32)->default('');
            $table->string('state', 2)->default('');
            $table->string('zip', 10)->default('');
            $table->string('country', 2)->default('US');
            $table->string('email', 100)->nullable();
            $table->string('phone', 24)->nullable();
            $table->text('remarks')->nullable();
            $table->double('latitude', 14, 11)->nullable();
            $table->double('longitude', 14, 11)->nullable();
            $table->boolean('show_online')->default(1);

            $table->softDeletesTz();
            $table->timestampsTz();

            $table->index('name');
            $table->index('parent_id');
            $table->index('company_id');
            $table->index('show_online');
            $table->index('state');
            $table->index(['latitude', 'longitude']);
            $table->index('deleted_at');
            $table->index('created_at');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('company_locations');
    }
};
