<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        if (!Schema::hasColumn('users', 'last_name') && !Schema::hasColumn('users', 'first_name') && Schema::hasColumn('users', 'name')) {
            Schema::table('users', function (Blueprint $table) {
                $table->renameColumn('name', 'first_name');
                $table->string('last_name', 255)->after('first_name');
            });
        }

        Schema::table('users', function (Blueprint $table) {
            $table->comment('Users: Our agents, staff, etc, not from MLS or other sources');
            $table->string('username', 50)->unique()->after('id');
            $table->boolean('active')->default(false)->after('password');
            $table->string('title', 100)->nullable()->after('active');
            $table->string('slug', 50)->unique()->after('title');
            $table->string('display_name', 255)->nullable()->after('slug');
            $table->string('familiar_name', 255)->nullable()->after('display_name');
            $table->string('phone_mobile', 24)->nullable()->after('familiar_name');
            $table->string('phone_office', 24)->nullable()->after('phone_mobile');
            $table->string('photo_url', 255)->nullable()->after('phone_office');
            $table->boolean('is_team')->default(false)->after('photo_url');
            $table->foreignId('team_user_id')
                ->nullable()
                ->after('is_team')
                ->constrained(
                    table: 'users', indexName: 'user_id'
                )
                ->nullOnDelete();
            $table->boolean('show_online')->default(false)->after('team_user_id');
            $table->text('remarks')->nullable()->after('show_online');

            $table->softDeletesTz();

            $table->dropUnique('users_email_unique');
            $table->index('email');
            $table->index('active');
            $table->index('show_online');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('users', function (Blueprint $table) {
            // Drop the newly added columns
            $table->dropColumn(['username', 'title', 'slug', 'display_name',
                'familiar_name', 'phone_mobile', 'phone_office', 'photo_url',
                'show_online', 'active', 'remarks']);

            $table->dropIndex('email');
            $table->unique('email'); // Default setting for Laravel
            $table->dropSoftDeletesTz();
        });

        if (Schema::hasColumn('users', 'last_name') && Schema::hasColumn('users', 'first_name')) {
            Schema::table('users', function (Blueprint $table) {
                // Revert 'first_name' back to 'name'
                $table->renameColumn('first_name', 'name');
                $table->dropColumn('last_name');
            });
        }
    }
};
