<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('open_houses', function (Blueprint $table) {
            $table->comment('Open Houses: From MLS and other sources');
            $table->id();
            $table->foreignId('listing_id')->nullable();
            $table->string('ion_source', 16); // Our source ID - CWS, RESO, DASH, MANUAL, etc
            $table->string('originating_system_name', 100)->default('');
            $table->enum('open_house_type', ['Broker', 'Office', 'Public'])->default('Public');
            $table->date('open_house_date')->nullable();
            $table->timeTz('open_house_start_time')->nullable();
            $table->timeTz('open_house_end_time')->nullable();
            $table->text('open_house_remarks')->nullable();
            $table->string('open_house_key', 64)->nullable();
            $table->dateTimeTz('modification_timestamp')->default(now());
            $table->foreignId('updated_by')->nullable();
            $table->softDeletes();
            $table->timestampsTz();

            $table->index('ion_source');
            $table->index('originating_system_name');
            $table->index('listing_id');
            $table->index('open_house_type');
            $table->index('open_house_date');
            $table->index('modification_timestamp');
            $table->index('deleted_at');
            $table->index('created_at');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('open_houses');
    }
};
