<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::table('companies', function (Blueprint $table) {
            $table->string('ion_source', 16)->default('Manual')->after('id');
            $table->string('ion_source_id', 32)->nullable()->after('ion_source');
            $table->json('metadata')
                ->comment('Additional field values')
                ->after('photo_url')
                ->nullable();
            $table->json('origdata')
                ->comment('Original values that have been overridden')
                ->after('metadata')
                ->nullable();
            $table->index('ion_source');
            $table->index('ion_source_id');
        });

        Schema::table('company_locations', function (Blueprint $table) {
            $table->string('ion_source', 16)->default('Manual')->after('id');
            $table->string('ion_source_id', 32)->nullable()->after('ion_source');
            $table->json('metadata')
                ->comment('Additional field values')
                ->after('show_online')
                ->nullable();
            $table->json('origdata')
                ->comment('Original values that have been overridden')
                ->after('metadata')
                ->nullable();
            $table->index('ion_source');
            $table->index('ion_source_id');
        });

        Schema::table('listings', function (Blueprint $table) {
            $table->json('metadata')
                ->comment('Additional field values')
                ->after('ion_duplicate_of')
                ->nullable();
            $table->json('origdata')
                ->comment('Original values that have been overridden')
                ->after('metadata')
                ->nullable();
        });

        Schema::table('users', function (Blueprint $table) {
            $table->string('ion_source', 16)->default('Manual')->after('username');
            $table->string('ion_source_id', 32)->nullable()->after('ion_source');
            $table->json('metadata')
                ->comment('Additional field values')
                ->after('remember_token')
                ->nullable();
            $table->json('origdata')
                ->comment('Original values that have been overridden')
                ->after('metadata')
                ->nullable();
            $table->index('ion_source');
            $table->index('ion_source_id');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('companies', function (Blueprint $table) {
            // Drop the newly added columns
            $table->dropColumn(['ion_source', 'ion_source_id', 'metadata', 'origdata']);
        });

        Schema::table('company_locations', function (Blueprint $table) {
            // Drop the newly added columns
            $table->dropColumn(['ion_source', 'ion_source_id', 'metadata', 'origdata']);
        });

        Schema::table('listings', function (Blueprint $table) {
            // Drop the newly added columns
            $table->dropColumn(['metadata', 'origdata']);
        });

        Schema::table('users', function (Blueprint $table) {
            // Drop the newly added columns
            $table->dropColumn(['ion_source', 'ion_source_id', 'metadata', 'origdata']);
        });
    }
};
