<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
	    Schema::table('listings', function (Blueprint $table) {
		    $table->string('listing_key', 255)->nullable()->default(null)->after('list_aor');
		    $table->string('high_school', 110)->nullable()->default(null)->after('building_name');
		    $table->string('elementary_school_district', 110)->nullable()->default(null)->after('high_school');
		    $table->string('elementary_school', 110)->nullable()->default(null)->after('elementary_school_district');
		    $table->string('middle_or_junior_school_district', 110)->nullable()->default(null)->after('elementary_school_district');
		    $table->string('middle_or_junior_school', 110)->nullable()->default(null)->after('middle_or_junior_school_district');
	    });

	    Schema::table('listings_extra_search_fields', function (Blueprint $table) {
		    $table->boolean('association_yn')->default(0)->after('association_fee');
		    $table->string('parcel_number', 55)->nullable()->default(null)->after('association_fee');
		    $table->string('appliances', 510)->nullable()->default(null)->after('parcel_number');
		    $table->string('architectural_style', 255)->nullable()->default(null)->after('appliances');
		    $table->string('basement', 255)->nullable()->default(null)->after('architectural_style');
		    $table->boolean('basement_yn')->default(0)->after('basement');
		    $table->string('common_walls', 255)->nullable()->default(null)->after('basement_yn');
		    $table->string('construction_materials', 255)->nullable()->default(null)->after('common_walls');
		    $table->string('cooling', 255)->nullable()->default(null)->after('construction_materials');
		    $table->string('fencing', 255)->nullable()->default(null)->after('cooling');
		    $table->string('heating', 255)->nullable()->default(null)->after('fencing');
		    $table->string('interior_features', 255)->nullable()->default(null)->after('heating');
		    $table->string('levels', 255)->nullable()->default(null)->after('interior_features');
		    $table->string('lot_features', 255)->nullable()->default(null)->after('levels');
		    $table->string('parking_features', 255)->nullable()->default(null)->after('lot_features');
		    $table->string('patio_and_porch_features', 255)->nullable()->default(null)->after('parking_features');
		    $table->string('pool_features', 255)->nullable()->default(null)->after('patio_and_porch_features');
		    $table->string('road_responsibility', 255)->nullable()->default(null)->after('pool_features');
		    $table->string('sewer', 255)->nullable()->default(null)->after('road_responsibility');
		    $table->string('syndicate_to', 255)->nullable()->default(null)->after('sewer');
		    $table->string('water_source', 255)->nullable()->default(null)->after('syndicate_to');
		    $table->boolean('pool_private_yn')->default(0)->after('water_source');
		    $table->boolean('property_attached_yn')->default(0)->after('pool_private_yn');
		    $table->boolean('spa_yn')->default(0)->after('property_attached_yn');
			$table->double('tax_annual_amount')->nullable()->after('spa_yn');
		    $table->string('fireplace_features', 255)->nullable()->default(null)->after('tax_annual_amount');
			$table->integer('fireplaces_total')->default(0)->after('fireplace_features');
		    $table->boolean('fireplace_yn')->default(0)->after('fireplaces_total');
		    $table->string('lease_term', 55)->nullable()->default(null)->after('fireplace_yn');
		    $table->string('pets_allowed', 1050)->nullable()->default(null)->after('lease_term');
		    $table->boolean('senior_community_yn')->default(0)->after('pets_allowed');
		    $table->string('spa_features', 1050)->nullable()->default(null)->after('senior_community_yn');
		    $table->string('topography', 255)->nullable()->default(null)->after('spa_features');
		    $table->boolean('view_yn')->default(0)->after('topography');
		    $table->string('view', 1050)->nullable()->default(null)->after('view_yn');
		    $table->string('water_body_name', 55)->nullable()->default(null)->after('view');
		    $table->string('waterfront_features', 1050)->nullable()->default(null)->after('water_body_name');
		    $table->boolean('waterfront_yn')->default(0)->after('waterfront_features');
		    $table->string('other_equipment', 1050)->nullable()->default(null)->after('water_body_name');
		    $table->string('security_features', 1050)->nullable()->default(null)->after('other_equipment');
		    $table->string('utilities', 1050)->nullable()->default(null)->after('security_features');
		    $table->boolean('electric_on_property_yn')->default(0)->after('utilities');
	    });

	    Schema::table('agents', function (Blueprint $table) {
		    $table->string('member_aor', 36)->nullable()->default(null)->after('originating_system_name');
		    $table->string('member_key', 255)->nullable()->default(null)->after('member_aor');
		    $table->string('member_direct_phone', 21)->nullable()->default(null)->after('member_office_phone');
		    $table->string('member_status', 25)->nullable()->default(null)->after('member_direct_phone');
		    $table->string('member_mls_security_class', 25)->nullable()->default(null)->after('member_status');
		    $table->string('member_type', 55)->nullable()->default(null)->after('member_mls_security_class');
		    $table->string('office_key', 255)->nullable()->default(null)->after('member_type');
		    $table->string('office_mls_id', 25)->nullable()->default(null)->after('office_key');
		    $table->dateTimeTz('modification_timestamp')->default(now())->after('office_mls_id');
	    });

	    Schema::table('offices', function (Blueprint $table) {
		    $table->string('office_aor', 36)->nullable()->default(null)->after('originating_system_name');
		    $table->string('office_key', 255)->nullable()->default(null)->after('office_aor');
		    $table->string('office_status', 25)->nullable()->default(null)->after('office_phone');
		    $table->string('office_type', 55)->nullable()->default(null)->after('office_status');
		    $table->dateTimeTz('modification_timestamp')->default(now())->after('office_type');
	    });

	    Schema::table('open_houses', function (Blueprint $table) {
		    $table->string('listing_key', 255)->nullable()->default(null)->after('originating_system_name');
		    $table->string('reso_listing_id', 36)->nullable()->default(null)->after('listing_key');
		    $table->string('office_key', 255)->nullable()->default(null)->after('reso_listing_id');
		    $table->string('office_mls_id', 36)->nullable()->default(null)->after('office_key');
		    $table->string('open_house_status', 36)->nullable()->default(null)->after('open_house_remarks');
		    $table->string('showing_agent_key', 255)->nullable()->default(null)->after('open_house_key');
		    $table->string('showing_agent_mls_id', 36)->nullable()->default(null)->after('showing_agent_key');
	    });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
	    Schema::table('listings', function (Blueprint $table) {
		    // Drop the newly added columns
		    $table->dropColumn([
				'listing_key',
			    'high_school',
				'elementary_school_district',
			    'elementary_school',
			    'middle_or_junior_school_district',
			    'middle_or_junior_school',
		    ]);
	    });

	    Schema::table('listings_extra_search_fields', function (Blueprint $table) {
		    // Drop the newly added columns
		    $table->dropColumn([
			    'parcel_number',
				'appliances',
			    'architectural_style',
			    'basement',
			    'basement_yn',
			    'common_walls',
			    'construction_materials',
			    'cooling',
			    'fencing',
			    'heating',
			    'interior_features',
			    'levels',
			    'lot_features',
			    'parking_features',
			    'patio_and_porch_features',
			    'pool_features',
			    'road_responsibility',
			    'sewer',
			    'syndicate_to',
			    'water_source',
			    'pool_private_yn',
			    'property_attached_yn',
			    'spa_yn',
			    'tax_annual_amount',
			    'fireplace_features',
			    'fireplaces_total',
			    'fireplace_yn',
			    'lease_term',
			    'pets_allowed',
			    'senior_community_yn',
			    'spa_features',
			    'topography',
			    'view_yn',
			    'view',
			    'water_body_name',
			    'waterfront_features',
			    'waterfront_yn',
			    'other_equipment',
			    'security_features',
			    'association_yn',
			    'utilities',
			    'electric_on_property_yn',
		    ]);
	    });

	    Schema::table('agents', function (Blueprint $table) {
		    // Drop the newly added columns
		    $table->dropColumn([
			    'member_aor',
			    'member_status',
			    'member_mls_security_class',
			    'member_type',
				'member_key',
			    'office_key',
			    'office_mls_id',
			    'modification_timestamp',
			    'member_direct_phone',
		    ]);
	    });

	    Schema::table('offices', function (Blueprint $table) {
		    // Drop the newly added columns
		    $table->dropColumn([
			    'office_aor',
			    'office_key',
			    'office_status',
			    'office_type',
			    'modification_timestamp',
		    ]);
	    });

	    Schema::table('open_houses', function (Blueprint $table) {
		    // Drop the newly added columns
		    $table->dropColumn([
			    'listing_key',
			    'reso_listing_id',
			    'office_key',
			    'office_mls_id',
			    'open_house_status',
			    'showing_agent_key',
			    'showing_agent_mls_id',
		    ]);
	    });
    }
};
