<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
	/**
	 * Run the migrations.
	 */
	public function up(): void
	{
		if (Schema::hasColumn('listings_media', 'source')) {
			Schema::table('listings_media', function (Blueprint $table) {
				$table->renameColumn('source', 'ion_source');
			});
		}

		if (Schema::hasColumn('listings_media', 'type')) {
			Schema::table('listings_media', function (Blueprint $table) {
				$table->renameColumn('type', 'media_type');
			});
		}

		if (Schema::hasColumn('listings_media', 'media_type')) {
			Schema::table('listings_media', function (Blueprint $table) {
				$table->renameColumn('media_type', 'media_category');
			});
		}

		if (Schema::hasColumn('listings_media', 'position')) {
			Schema::table('listings_media', function (Blueprint $table) {
				$table->renameColumn('position', 'order');
			});
		}

		if (Schema::hasColumn('listings_media', 'url')) {
			Schema::table('listings_media', function (Blueprint $table) {
				$table->renameColumn('url', 'media_url');
			});
		}

		if (Schema::hasColumn('listings_media', 'caption')) {
			Schema::table('listings_media', function (Blueprint $table) {
				$table->renameColumn('caption', 'long_description');
			});
		}

		if (Schema::hasColumn('listings_media', 'width')) {
			Schema::table('listings_media', function (Blueprint $table) {
				$table->renameColumn('width', 'image_width');
			});
		}

		if (Schema::hasColumn('listings_media', 'height')) {
			Schema::table('listings_media', function (Blueprint $table) {
				$table->renameColumn('height', 'image_height');
			});
		}

		Schema::table('listings_media', function (Blueprint $table) {
			$table->text('media_html')->nullable()->default(null)->after('media_url');
			$table->string('long_description', 1055)->nullable()->default(null)->change();
			$table->string('originating_system_name', 100)->after('ion_source');
			$table->string('resource_name', 55)->nullable()->default(null)->after('ion_source');
			$table->string('resource_record_id', 255)->nullable()->default(null)->after('resource_name');
			$table->string('resource_record_key', 255)->nullable()->default(null)->after('resource_record_id');
			$table->string('media_key', 255)->nullable()->default(null)->after('resource_record_key');
			$table->string('media_type', 55)->nullable()->default(null)->after('media_category');
			$table->string('media_status', 55)->nullable()->default(null)->after('media_category');
			$table->string('short_description', 55)->nullable()->default(null)->after('long_description');
			$table->string('image_of', 55)->nullable()->default(null)->after('short_description');
			$table->string('permission', 255)->nullable()->default(null)->after('resource_record_key');
			$table->boolean('preferred_photo_yn')->default(0)->after('order');
			$table->dateTimeTz('modification_timestamp')->default(now())->after('image_height');
		});
	}

	/**
	 * Reverse the migrations.
	 */
	public function down(): void
	{
		Schema::table('listings_media', function (Blueprint $table) {
			// Drop the newly added columns
			$table->dropColumn([
				'modification_timestamp',
				'originating_system_name',
				'resource_name',
				'resource_record_id',
				'resource_record_key',
				'media_key',
				'media_category',
				'media_status',
				'short_description',
				'image_of',
				'permission',
				'media_html',
				'preferred_photo_yn',
			]);
		});
	}
};
