<?php

namespace Neutrino\Ion3Core\Database\Seeders;

// use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use App\Ion3\Models\Agent;
use App\Ion3\Models\Company;
use App\Ion3\Models\CompanyLocation;
use App\Ion3\Models\Listing;
use App\Ion3\Models\ListingMedia;
use App\Ion3\Models\Office;
use App\Ion3\Models\OpenHouse;
use App\Models\User;
use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\DB;
use Neutrino\Ion3Core\Models\Ion3CompanyLocationOfficeSource;
use Neutrino\Ion3Core\Models\Ion3UserAgentSource;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     */
    public function run(): void
    {
        // Required records should already have been created with DatabaseRequiredSeeder()
        $company = Company::find(1);

        // Create other users and fake data
        User::factory(9)->create()->each(function ($user) {
            $user->assignRole('agent');
        });;
        $this->call(ListingSeeder::class);
        $this->call(OfficeSeeder::class);

        // A few company locations
        CompanyLocation::factory(5)->create([
            'company_id' => $company->id,
        ]);

        // Sync up listings with agents and offices
        $listings = Listing::all();
        $agents = Agent::all();

        foreach ($listings as $listing) {
            $selectedAgents = $agents->random(rand(1, 4));
            foreach ($selectedAgents as $key => $agent) {
                if ($key < 2) {
                    $type = 'selling';
                } else {
                    $type = 'buying';
                }
                $listing->agents()->attach($agent->id, [
                    'active' => true,
                    'type' => $type,
                    'position' => ($key % 2) + 1
                ]);

                $listing->offices()->attach($agent->office->id, [
                    'active' => true,
                    'type' => $type,
                    'position' => ($key % 2) + 1
                ]);
            }

            // Add some media too
            $mediaCount = rand(1, 10);
            for ($position = 0; $position < $mediaCount; $position++) {
                ListingMedia::create([
                    'listing_id' => $listing->id,
                    'originating_system_name' => '',
                    'ion_source' => 'Manual',
                    'media_category' => 'Photo',
                    'order' => $position,
                    'media_url' => fake()->imageUrl(),
                    'long_description' => fake()->sentence(),
                ]);
            }

            // Add open houses
            if (rand(1, 10) === 1) {
                OpenHouse::factory(rand(1,3))->create([
                    'listing_id' => $listing->id,
                ]);
            }
        }

        // Add source values for agents and offices
        // First, create agent source values for users, 1 agent per user
        $users = User::with('agentSources')->inRandomOrder()->take(10)->get();
        $agents = Agent::inRandomOrder()->take(10)->get();
        foreach($users as $k => $user) {
            $currentAgent = $agents[$k];
            Ion3UserAgentSource::create([
                'user_id' => $user->id,
                'source' => $currentAgent->ion_source,
                'source_id' => $currentAgent->member_mls_id,
            ]);
            $currentAgent->update(['user_id' => $user->id]);
        }

        // Now, do the same on company locations
        $companyLocations = CompanyLocation::with('officeSources')->get();
        $agentsWithUsersOfficeIDs = Agent::whereNotNull('user_id')
            ->pluck('office_id')
            ->toArray();
        $offices = Office::whereIn('id', $agentsWithUsersOfficeIDs)
            ->take($companyLocations->count())
            ->get();
        foreach($companyLocations as $k => $location) {
            if (isset($offices[$k])) {
                $currentOffice = $offices[$k];
                Ion3CompanyLocationOfficeSource::create([
                    'company_location_id' => $location->id,
                    'source' => $currentOffice->ion_source,
                    'source_id' => $currentOffice->office_mls_id,
                ]);
                $currentOffice->update(['company_location_id' => $location->id]);
            }
        }

        // Assign users to company locations based on those connections
        // This could certainly be optimized
        foreach($users as $user) {
            $agent = Agent::where('user_id', $user->id)->first();
            if ($agent) {
                $office = Office::find($agent->office_id);
                if ($office->company_location_id) {
                    $companyLocation = CompanyLocation::find($office->company_location_id);
                    $companyLocation->users()->attach($user->id);
                }
            }
        }
    }
}
