<?php

namespace Neutrino\Ion3Core\Database\Seeders;

use Illuminate\Database\Seeder;
use Spatie\Permission\Models\Role;
use Spatie\Permission\Models\Permission;

class RolesAndPermissionsSeeder extends Seeder
{
    public function run(): void
    {
        // Reset cached roles and permissions
        app()[\Spatie\Permission\PermissionRegistrar::class]->forgetCachedPermissions();

        // create permissions
        Permission::create(['name' => 'view_company']);
        Permission::create(['name' => 'view_office_company']);
        Permission::create(['name' => 'view_any_company']);
        Permission::create(['name' => 'create_company']);
        Permission::create(['name' => 'update_company']);
        Permission::create(['name' => 'restore_company']);
        Permission::create(['name' => 'restore_office_company']);
        Permission::create(['name' => 'restore_any_company']);
        Permission::create(['name' => 'replicate_company']);
        Permission::create(['name' => 'delete_company']);
        Permission::create(['name' => 'delete_office_company']);
        Permission::create(['name' => 'delete_any_company']);

        Permission::create(['name' => 'view_company::location']);
        Permission::create(['name' => 'view_office_company::location']);
        Permission::create(['name' => 'view_any_company::location']);
        Permission::create(['name' => 'create_company::location']);
        Permission::create(['name' => 'update_company::location']);
        Permission::create(['name' => 'restore_company::location']);
        Permission::create(['name' => 'restore_office_company::location']);
        Permission::create(['name' => 'restore_any_company::location']);
        Permission::create(['name' => 'replicate_company::location']);
        Permission::create(['name' => 'delete_company::location']);
        Permission::create(['name' => 'delete_office_company::location']);
        Permission::create(['name' => 'delete_any_company::location']);

        Permission::create(['name' => 'view_listing']);
        Permission::create(['name' => 'view_office_listing']);
        Permission::create(['name' => 'view_any_listing']);
        Permission::create(['name' => 'create_listing']);
        Permission::create(['name' => 'update_listing']);
        Permission::create(['name' => 'restore_listing']);
        Permission::create(['name' => 'restore_office_listing']);
        Permission::create(['name' => 'restore_any_listing']);
        Permission::create(['name' => 'replicate_listing']);
        Permission::create(['name' => 'delete_listing']);
        Permission::create(['name' => 'delete_office_listing']);
        Permission::create(['name' => 'delete_any_listing']);

        Permission::create(['name' => 'view_role']);
        Permission::create(['name' => 'view_any_role']);
        Permission::create(['name' => 'create_role']);
        Permission::create(['name' => 'update_role']);
        Permission::create(['name' => 'delete_role']);
        Permission::create(['name' => 'delete_any_role']);

        Permission::create(['name' => 'view_user']);
        Permission::create(['name' => 'view_office_user']);
        Permission::create(['name' => 'view_any_user']);
        Permission::create(['name' => 'create_user']);
        Permission::create(['name' => 'update_user']);
        Permission::create(['name' => 'update_admin_data_user']);
        Permission::create(['name' => 'restore_user']);
        Permission::create(['name' => 'restore_office_user']);
        Permission::create(['name' => 'restore_any_user']);
        Permission::create(['name' => 'replicate_user']);
        Permission::create(['name' => 'delete_user']);
        Permission::create(['name' => 'delete_office_user']);
        Permission::create(['name' => 'delete_any_user']);

        // Create one more permission for sysadmin access
        Permission::create(['name' => 'sysadmin']);

        // create roles and assign created permissions
        $role = Role::create(['name' => 'super_admin']);
        $role->givePermissionTo(Permission::whereNotLike('name', '%\_role')->where('name', '!=', 'sysadmin')->get());

        $role = Role::create(['name' => 'agent']);
        $role->givePermissionTo([
            'view_listing',
            'create_listing',
            'update_listing',
            'restore_listing',
            'delete_listing',
            'view_user',
            'update_user',
        ]);

        $role = Role::create(['name' => 'office_manager']);
        $role->givePermissionTo([
            'view_company::location',
            'update_company::location',
            'view_listing',
            'view_office_listing',
            'create_listing',
            'update_listing',
            'restore_listing',
            'restore_office_listing',
            'delete_listing',
            'delete_office_listing',
            'view_user',
            'view_office_user',
            'create_user',
            'update_user',
            'update_admin_data_user',
            'restore_user',
            'restore_office_user',
            'delete_user',
            'delete_office_user',
        ]);

        // create roles and assign created permissions
        $role = Role::create(['name' => 'super_sysadmin']);
        $role->givePermissionTo(Permission::all());
    }
}
