<?php

namespace Neutrino\Ion3Core\Console\Commands;

use Illuminate\Console\Command;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Enums\Ion3ConsoleCommandNamespace;
use Neutrino\Ion3Core\Enums\Ion3DataSource;
use Illuminate\Support\Facades\Artisan;

class Ion3ImportOpenHouses extends Command
{
	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'ion3:import-openhouses 
							{--s|--dataSource= : Data Source (CWS|CIRE|[Custom])}
							{--o|--originatingSystemName= : RESO OriginatingSystemName} 
							{--m|--listingId= : RESO ListingId}
							{--k|--listingKey= : RESO ListingKey}
							{--modificationTimestamp= : RESO ModificationTimestamp Range (\'YYYY-MM-DD[ |T]HH:MM:SS\' OR \'YYYY-MM-DD[ |T]HH:MM:SS-YYYY-MM-DD[ |T]HH:MM:SS\')}
							{--goback= : Based on RESO ModificationTimestamp, go back (N [second(s)|minute(s)|hour(s)|day(s)|week(s)|month(s)|year(s)])}
							{--orderby=}
							{--top= : How many records to return at a time}
							{--limit= : How many records to return in total}
							{--offset=}
							{--dump}';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = "Ion3 Import OpenHouses";

	public function __construct()
	{
		parent::__construct();

		if (function_exists('set_time_limit')) {
			set_time_limit(0);
		}

		$ion3CoreLoggingConfigPath = base_path('vendor-local/neutrino/ion3-core/config/logging.php');
		$ion3CoreLoggingConfig = require $ion3CoreLoggingConfigPath;

		Config::set('logging.channels', array_merge(
			Config::get('logging.channels'),
			$ion3CoreLoggingConfig['channels']
		));
	}

	/**
	 * Execute the console command.
	 */
	public function handle()
	{
		try {

			Log::channel('ion3openhouseimports')->info('BEGIN: Import OpenHouses');

			$availableDataSources = array_keys(Ion3DataSource::asArray(true));

			if (is_null($dataSource = $this->option('dataSource'))) {
				$this->error("The --dataSource option is required (" . implode("|", $availableDataSources) . "|[Custom])");
				return 1;
			}

			switch(true) {
				case in_array($dataSource, $availableDataSources):
					$consoleCommandClass = Ion3ConsoleCommandNamespace::asArray(true)['CORE'] . '\\' . "{$dataSource}ImportOpenHouses";
					if(!class_exists($consoleCommandClass)) {
						$this->error(
							"Unable to locate following Console Command file: {$consoleCommandClass}...");
						return 1;
					}
					$argsAndOptions = ($consoleCommandClass)::transformRESOOptions(array_merge($this->arguments(), $this->options()));
					break;
				default:
					$consoleCommandClass = Ion3ConsoleCommandNamespace::asArray(true)['CLIENT'] . '\\' . "{$dataSource}ImportOpenHouses";
					if(!class_exists($consoleCommandClass)) {
						$this->error(
							"Unavailable --dataSource ({$dataSource}) value, available options are (" . implode("|", $availableDataSources) . "|[Custom]):
 - 'Custom' must exist in following Namespace: " . Ion3ConsoleCommandNamespace::asArray(true)['CLIENT'] . "
 - File name structure must match following format: {$dataSource}ImportOpenHouses.php");
						return 1;
					}
					$argsAndOptions = ($consoleCommandClass)::transformRESOOptions(array_merge($this->arguments(), $this->options()));
					break;
			}

			Artisan::call($consoleCommandClass, $argsAndOptions);

		} catch (\Exception $e) {
			Log::channel('ion3openhouseimports')->info("\nERROR: " . $e->getMessage() . " (" . $e->getFile() . " at line " . $e->getLine() . ")");
		}

	}

}
