<?php

namespace Neutrino\Ion3Core\Console\Commands;

use App\Models\User;
use Illuminate\Console\Command;
use Spatie\Permission\Models\Permission;

class Ion3SeedCommand extends Command
{
    protected $signature = 'ion3:seed
                            {--r|required : Required data only}
                            {--l|listings=100 : How many listings to generate}';

    protected $description = 'Seed the Ion3 database tables with dummy data.';

    public function handle()
    {
        // Check if our Ion3 custom models exist, and if not let the user know
        try {
            class_exists(\App\Ion3\Models\Listing::class);
        } catch (\Throwable $e) {
            $this->line("\e[31mIon3 not installed, please run\e[0m php artisan vendor:publish --tag=ion3-install");
            return 1;
        }

        // Set number of listings for later reference
        $numberOfListings = $this->option('listings');
        app()->singleton('ion3SeedListingsCount', function() use ($numberOfListings) {
            return $numberOfListings;
        });

        // Always call required data
        if (!Permission::exists()) {
            $this->call('db:seed', [
                '--class' => \Neutrino\Ion3Core\Database\Seeders\DatabaseRequiredSeeder::class
            ]);
        }

        if (!$this->option('required')) {
            // We want dummy data too
            $this->call('db:seed', [
                '--class' => \Neutrino\Ion3Core\Database\Seeders\DatabaseSeeder::class
            ]);
        }
        echo "Required: ";

        $this->info('Ion3 seeding complete.');

        return 0; // Success
    }
}
