<?php

namespace Neutrino\Ion3Core;

use Illuminate\Contracts\Events\Dispatcher;
use Illuminate\Support\Facades\Event;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\ServiceProvider;
use Neutrino\Ion3Core\Console\Commands\Ion3CancelBatch;
use Neutrino\Ion3Core\Events\Ion3Updated;
use Neutrino\Ion3Core\Listeners\Ion3UpdateMetadata;

class Ion3CoreServiceProvider extends ServiceProvider
{
    /**
     * Register services.
     */
    public function register(): void
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
	            \Neutrino\Ion3Core\Console\Commands\Ion3CancelBatch::class,
                \Neutrino\Ion3Core\Console\Commands\Ion3SeedCommand::class,
	            \Neutrino\Ion3Core\Console\Commands\Ion3ImportListings::class,
	            \Neutrino\Ion3Core\Console\Commands\Ion3ImportAgents::class,
	            \Neutrino\Ion3Core\Console\Commands\Ion3ImportOffices::class,
	            \Neutrino\Ion3Core\Console\Commands\Ion3ImportOpenHouses::class,
	            \Neutrino\Ion3Core\Console\Commands\Ion3ImportMedia::class,
	            \Neutrino\Ion3Core\Console\Commands\CWSImportListings::class,
	            \Neutrino\Ion3Core\Console\Commands\CWSImportAgents::class,
	            \Neutrino\Ion3Core\Console\Commands\CWSImportOffices::class,
	            \Neutrino\Ion3Core\Console\Commands\CWSImportOpenHouses::class,
	            \Neutrino\Ion3Core\Console\Commands\CWSImportMedia::class,
            ]);
        }

        $this->app->singleton('ion3', function ($app) {
            return new Ion3Utility();
        });

        $this->loadViewsFrom(
            __DIR__ . '/../resources/views', 'ion3'
        );
    }

    /**
     * Bootstrap services.
     */
    public function boot(): void
    {
        if (app()->runningInConsole()) {
            $this->loadMigrationsFrom(__DIR__ . '/../database/migrations');

            // Publish config
            $this->publishes([
                __DIR__.'/../config/config.php' => config_path('ion3.php'),
            ], 'ion3-install');

            // Publish models
            $this->publishes([
                __DIR__ . '/../stubs/Models' => base_path('app/Ion3/Models'),
                __DIR__ . '/../stubs/ModelOverrides' => base_path('app/Models'),
                //__DIR__.'/../stubs/Http/Controllers' => base_path('app/Ion3/Http/Controllers'),
            ], 'ion3-install');

            /*
            $this->publishes([
                __DIR__.'/../config/ion3.php' => config_path('ion3.php'),
            ], 'ion3-config');
            */
        }

        $this->loadRoutesFrom(
            __DIR__ . '/../routes/ion3.php'
        );

        // Heads-up that any Ion3Metadata objects you want will need the Ion3Metadata trait, metadata/origdata casts and
        // guarded values, and $dispatchesEvents attribute set.
        Event::listen(
            Ion3Updated::class,
            Ion3UpdateMetadata::class
        );
    }
}
