<?php

namespace Neutrino\Ion3Core\Jobs;

use Illuminate\Bus\Batchable;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Log;

use Neutrino\Ion3Core\Models\Ion3Agent;
use Neutrino\Ion3Core\Services\CWSClient;
use Neutrino\Ion3Core\Transformers\Ion3AgentDataTransformer;
use Neutrino\Ion3Core\Enums\Ion3DataSource;

class CWSImportAgentJob implements ShouldQueue
{
	use Batchable, Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

	public static $dataSourceHandle = "CWS";

	public $record;

	/**
	 * Create a new job instance.
	 */
	public function __construct($record)
	{
		$ion3CoreLoggingConfigPath = base_path('vendor-local/neutrino/ion3-core/config/logging.php');
		$ion3CoreLoggingConfig = require $ion3CoreLoggingConfigPath;

		Config::set('logging.channels', array_merge(
			Config::get('logging.channels'),
			$ion3CoreLoggingConfig['channels']
		));

		$this->record = $record;
	}

	/**
	 * Execute the job.
	 */
	public function handle(): void
	{
		Log::channel(CWSClient::getLogChannel(CWSClient::$MemberEntity))->info("Importing CWS Agent (MemberMlsId: {$this->record['MemberMlsId']} | MemberKey: {$this->record['MemberKey']}) from {$this->record['OriginatingSystemName']}" . ((isset($this->record['MemberAOR']) ? ":{$this->record['MemberAOR']}" : "")) .  ($this->job ? " (Queue: " . $this->job->getQueue() . ")" : ""));

		$AgentDataTransformer = new Ion3AgentDataTransformer();
		$transformedAgentData = $AgentDataTransformer->transformData(Ion3DataSource::CWS->getKey(), $this->record);

		Ion3Agent::updateOrCreate([
			'ion_source' => $transformedAgentData['base']['ion_source'],
			'originating_system_name' => $transformedAgentData['base']['originating_system_name'],
			'member_key' => $transformedAgentData['base']['member_key'],
		], $transformedAgentData['base']);
	}
}
