<?php

namespace Neutrino\Ion3Core\Jobs;

use Neutrino\Ion3Core\Models\Ion3ListingMedia;
use Illuminate\Bus\Batchable;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Models\Ion3Listing;
use Neutrino\Ion3Core\Jobs\CWSImportListingJob;
use Neutrino\Ion3Core\Services\CWSClient;
use Neutrino\Ion3Core\Transformers\Ion3MediaDataTransformer;
use Neutrino\Ion3Core\Transformers\Ion3ListingDataTransformer;
use Neutrino\Ion3Core\Enums\Ion3DataSource;

class CWSImportMediaJob implements ShouldQueue
{
	use Batchable, Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

	public static $dataSourceHandle = "CWS";

	public $record;

	/**
	 * Create a new job instance.
	 */
	public function __construct($record)
	{
		$ion3CoreLoggingConfigPath = base_path('vendor-local/neutrino/ion3-core/config/logging.php');
		$ion3CoreLoggingConfig = require $ion3CoreLoggingConfigPath;

		Config::set('logging.channels', array_merge(
			Config::get('logging.channels'),
			$ion3CoreLoggingConfig['channels']
		));

		$this->record = $record;
	}

	/**
	 * Execute the job.
	 */
	public function handle(): void
	{
		Log::channel(CWSClient::getLogChannel(CWSClient::$MediaEntity))->info("Importing CWS Media Data (MediaCategory: {$this->record['MediaCategory']} | MediaKey: {$this->record['MediaKey']} | ResourceRecordID: {$this->record['ResourceRecordID']} | ResourceRecordKey: {$this->record['ResourceRecordKey']}) from {$this->record['OriginatingSystemName']}" .  ($this->job ? " (Queue: " . $this->job->getQueue() . ")" : ""));

		$MediaDataTransformer = new Ion3MediaDataTransformer();
		$transformedMediaData = $MediaDataTransformer->transformData(Ion3DataSource::CWS->getKey(), $this->record);

		$Listing = Ion3Listing::where('ion_source', 'cws')
		                      ->where('originating_system_name', $transformedMediaData['base']['originating_system_name']);

		switch(true) {
			case isset($transformedMediaData['base']['resource_record_key']):
				$listingKey = 'listing_key';
				$mediaKey = 'resource_record_key';
				break;
			case isset($transformedMediaData['base']['resource_record_id']):
				$listingKey = 'listing_id';
				$mediaKey = 'resource_record_id';
				break;
		}

		try {

			$Listing = $Listing->where($listingKey, $transformedMediaData['base'][$mediaKey])
			                   ->firstOrFail();

			$transformedMediaData['base']['listing_id'] = $Listing->id;
			Ion3ListingMedia::updateOrCreate([
				'ion_source' => $transformedMediaData['base']['ion_source'],
				'originating_system_name' => $transformedMediaData['base']['originating_system_name'],
				'media_key' => $transformedMediaData['base']['media_key'],
			], $transformedMediaData['base']);

			$Listing->update([
				'process_media' => 0
			]);

		} catch (\Exception $e) {

			Log::channel(CWSClient::getLogChannel(CWSClient::$MediaEntity))->info("No associated listing found in Ion3 or CWS (ListingId: " . ($this->record['ResourceRecordID'] ?? "N/A") . " | ListingKey: " . ($this->record['ResourceRecordKey'] ?? "N/A") . ") within {$this->record['OriginatingSystemName']}, skipping Media record...");

			/**
			$CWSClient = new CWSClient();

			switch(true) {
				case isset($transformedMediaData['base']['resource_record_key']):
					$filterKey = 'ListingKey';
					break;
				case isset($transformedMediaData['base']['resource_record_id']):
					$filterKey = 'ListingId';
					break;
			}

			$params = [
				"\$filter" => "OriginatingSystemName eq '{$transformedMediaData['base']['originating_system_name']}' and {$filterKey} in ('{$transformedMediaData['base'][$mediaKey]}')",
				"\$expand" => "",
				"\$top" => 100,
				"\$orderby" => "ListingKey asc",
				"\$ignorenulls" => "true",
				"\$select" => "",
			];

			$results = $CWSClient->search(CWSClient::$PropertyEntity, $params);

			if(isset($results['records'])) {
				(new CWSImportListingJob($results['records'][0]))->handle();
				$Listing = $Listing->firstOrFail();
			}
			**/
		}

		/**
		if($Listing instanceof (new Ion3Listing())) {
			$transformedMediaData['base']['listing_id'] = $Listing->id;
			Ion3ListingMedia::updateOrCreate([
				'ion_source' => $transformedMediaData['base']['ion_source'],
				'originating_system_name' => $transformedMediaData['base']['originating_system_name'],
				'media_key' => $transformedMediaData['base']['media_key'],
			], $transformedMediaData['base']);

			$Listing->update([
				'process_media' => 0
			]);
		} else {
			Log::channel(CWSClient::getLogChannel(CWSClient::$MediaEntity))->info("No associated listing found in Ion3 or CWS (ListingId: " . ($this->record['ResourceRecordID'] ?? "N/A") . " | ListingKey: " . ($this->record['ResourceRecordKey'] ?? "N/A") . ") within {$this->record['OriginatingSystemName']}, skipping Media record...");
		}
		**/
	}
}
