<?php

namespace Neutrino\Ion3Core\Jobs;

use Illuminate\Bus\Batchable;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Models\Ion3Office;
use Neutrino\Ion3Core\Services\CWSClient;
use Neutrino\Ion3Core\Transformers\Ion3OfficeDataTransformer;
use Neutrino\Ion3Core\Enums\Ion3DataSource;

class CWSImportOfficeJob implements ShouldQueue
{
	use Batchable, Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

	public static $dataSourceHandle = "CWS";

	public $record;

	/**
	 * Create a new job instance.
	 */
	public function __construct($record)
	{
		$ion3CoreLoggingConfigPath = base_path('vendor-local/neutrino/ion3-core/config/logging.php');
		$ion3CoreLoggingConfig = require $ion3CoreLoggingConfigPath;

		Config::set('logging.channels', array_merge(
			Config::get('logging.channels'),
			$ion3CoreLoggingConfig['channels']
		));

		$this->record = $record;
	}

	/**
	 * Execute the job.
	 */
	public function handle(): void
	{
		Log::channel(CWSClient::getLogChannel(CWSClient::$OfficeEntity))->info("Importing CWS Office (OfficeMlsId: {$this->record['OfficeMlsId']} | OfficeKey: {$this->record['OfficeKey']}) from {$this->record['OriginatingSystemName']}" . (isset($this->record['OfficeAOR']) ? ":{$this->record['OfficeAOR']}" : "") .  ($this->job ? " (Queue: " . $this->job->getQueue() . ")" : ""));

		$OfficeDataTransformer = new Ion3OfficeDataTransformer();
		$transformedOfficeData = $OfficeDataTransformer->transformData(Ion3DataSource::CWS->getKey(), $this->record);

		Ion3Office::updateOrCreate([
			'ion_source' => $transformedOfficeData['base']['ion_source'],
			'originating_system_name' => $transformedOfficeData['base']['originating_system_name'],
			'office_key' => $transformedOfficeData['base']['office_key'],
		], $transformedOfficeData['base']);
	}
}
