<?php

namespace Neutrino\Ion3Core\Jobs;

use Neutrino\Ion3Core\Models\Ion3OpenHouse;
use Illuminate\Bus\Batchable;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Models\Ion3Listing;
use Neutrino\Ion3Core\Services\CWSClient;
use Neutrino\Ion3Core\Transformers\Ion3OpenHouseDataTransformer;
use Neutrino\Ion3Core\Transformers\Ion3ListingDataTransformer;
use Neutrino\Ion3Core\Enums\Ion3DataSource;
use Neutrino\Ion3Core\Jobs\CWSImportListingJob;

class CWSImportOpenHouseJob implements ShouldQueue
{
	use Batchable, Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

	public static $dataSourceHandle = "CWS";

	public $record;

	/**
	 * Create a new job instance.
	 */
	public function __construct($record)
	{
		$ion3CoreLoggingConfigPath = base_path('vendor-local/neutrino/ion3-core/config/logging.php');
		$ion3CoreLoggingConfig = require $ion3CoreLoggingConfigPath;

		Config::set('logging.channels', array_merge(
			Config::get('logging.channels'),
			$ion3CoreLoggingConfig['channels']
		));

		$this->record = $record;
	}

	/**
	 * Execute the job.
	 */
	public function handle(): void
	{
		Log::channel(CWSClient::getLogChannel(CWSClient::$OpenHouseEntity))->info("Importing CWS Open House Data (OpenHouseKey: {$this->record['OpenHouseKey']} | ListingId: {$this->record['ListingId']} | ListingKey: {$this->record['ListingKey']}) from {$this->record['OriginatingSystemName']}" .  ($this->job ? " (Queue: " . $this->job->getQueue() . ")" : ""));

		$OpenHouseDataTransformer = new Ion3OpenHouseDataTransformer();
		$transformedOpenHouseData = $OpenHouseDataTransformer->transformData(Ion3DataSource::CWS->getKey(), $this->record);

		$Listing = Ion3Listing::where('originating_system_name', $transformedOpenHouseData['base']['originating_system_name']);

		switch(true) {
			case isset($transformedOpenHouseData['base']['listing_key']):
				$key = 'listing_key';
				break;
			case isset($transformedOpenHouseData['base']['reso_listing_id']):
				$key = 'reso_listing_id';
				break;
		}

		try {
			$Listing = $Listing->where($key, $transformedOpenHouseData['base'][$key])->firstOrFail();
		} catch (\Exception $e) {

			$CWSClient = new CWSClient();

			switch(true) {
				case isset($transformedOpenHouseData['base']['listing_key']):
					$filterKey = 'ListingKey';
					break;
				case isset($transformedOpenHouseData['base']['reso_listing_id']):
					$filterKey = 'ListingId';
					break;
			}

			$params = [
				"\$filter" => "OriginatingSystemName eq '{$transformedOpenHouseData['base']['originating_system_name']}' and {$filterKey} in ('{$transformedOpenHouseData['base'][$key]}')",
				"\$expand" => "",
				"\$top" => 100,
				"\$orderby" => "ListingKey asc",
				"\$ignorenulls" => "true",
				"\$select" => "",
			];

			$results = $CWSClient->search(CWSClient::$PropertyEntity, $params);

			if(isset($results['records'])) {
				(new CWSImportListingJob($results['records'][0]))->handle();
				$Listing = $Listing->firstOrFail();
			}
		}

		if($Listing instanceof (new Ion3Listing())) {
			$transformedOpenHouseData['base']['listing_id'] = $Listing->id;
			Ion3OpenHouse::updateOrCreate([
				'ion_source' => $transformedOpenHouseData['base']['ion_source'],
				'originating_system_name' => $transformedOpenHouseData['base']['originating_system_name'],
				'open_house_key' => $transformedOpenHouseData['base']['open_house_key'],
			], $transformedOpenHouseData['base']);
		} else {
			Log::channel(CWSClient::getLogChannel(CWSClient::$OpenHouseEntity))->info("No associated listing found in Ion3 or CWS (ListingId: " . ($this->record['ListingId'] ?? "N/A") . " | ListingKey: " . ($this->record['ListingKey'] ?? "N/A") . ") within {$this->record['OriginatingSystemName']}, skipping Open House...");
		}
	}
}
