<?php

namespace Neutrino\Ion3Core\Services;

use GuzzleHttp\Client;
use Illuminate\Support\Facades\Config;
use Neutrino\Ion3Core\Services\TokenService;

class CWSTokenService extends TokenService
{
	public function __construct()
	{
		$this->setCacheKeyPrefix('cws');
		$this->setClientId(Config::get('services.constellation1.client_id'));
		$this->setClientSecret(Config::get('services.constellation1.client_secret'));
		$this->setAuthBaseUrl(Config::get('services.constellation1.auth_base_url'));
	}

	/**
	 * Request a new access token from the OAuth2 server.
	 */
	protected function requestAccessToken()
	{

		$this->setAuthToken($this->generateAuthToken());

		$client = new Client();

		$response = $client->post($this->authBaseUrl, [
			'headers' => [
				"Content-Type" => "application/x-www-form-urlencoded",
				"Authorization" => "Basic {$this->authToken}",
				"Host" => parse_url($this->authBaseUrl, PHP_URL_HOST),
			],
			'form_params' => [
				'grant_type' => 'client_credentials',
				'client_id' => $this->clientId
			],
		]);

		$responseBody = json_decode($response->getBody()->getContents());

		$this->setAccessToken($responseBody->access_token, $responseBody->expires_in);

		return $responseBody->access_token;
	}

	protected function generateAuthToken() {
		return base64_encode("{$this->clientId}:{$this->clientSecret}");
	}
}