<?php

namespace Neutrino\Ion3Core\Services;

use GuzzleHttp\Client;
use Illuminate\Support\Facades\Cache;

class TokenService
{
	protected $cacheKeyPrefix;
	protected $clientId;
	protected $clientSecret;
	protected $authBaseUrl;
	protected $authToken;

	public function __construct() {}

	/**
	 * Get the access token, refresh it if expired.
	 */
	public function getAccessToken(): string
	{
		if (Cache::has("{$this->cacheKeyPrefix}_access_token")) {
			return Cache::get("{$this->cacheKeyPrefix}_access_token");
		}

		$token = $this->requestAccessToken();

		return $token;
	}

	/**
	 * Request a new access token from the OAuth2 server.
	 */
	protected function requestAccessToken() {}

	protected function setAccessToken($accessToken, $expiresIn) {
		Cache::put("{$this->cacheKeyPrefix}_access_token", $accessToken, now()->addSeconds($expiresIn));
	}

	protected function setClientId($clientId) {
		$this->clientId = $clientId;
	}

	protected function setAuthBaseUrl($authBaseUrl) {
		$this->authBaseUrl = $authBaseUrl;
	}

	protected function setClientSecret($clientSecret) {
		$this->clientSecret = $clientSecret;
	}

	protected function setCacheKeyPrefix($cacheKeyPrefix) {
		$this->cacheKeyPrefix = $cacheKeyPrefix;
	}

	protected function setAuthToken($authToken) {
		$this->authToken = $authToken;
	}
}