<?php

namespace Neutrino\Ion3Core\Traits;

use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Schema;

trait Ion3SearchTrait {
    public function toDefaultSearchableArray()
    {
        // Set basic field data for typesense db
        $data = [];
        $table = $this->getTable();
        $dataFields = config('scout.typesense.model-settings.'.self::class.'.collection-schema.fields');
//dd($this);
        foreach ($dataFields as $field) {
            if (isset($this->{$field['name']})) {
                // Switch based on MySQL column type
                switch(Schema::getColumnType($table, $field['name'])) {
                    case 'date':
                    case 'datetime':
                    case 'timestamp':
                        // Convert time to ints
                        if (!empty($this->{$field['name']})) {
                            try {
                                $value = $this->{$field['name']};
                                if (is_object($value) && property_exists($value, 'timestamp')) {
                                    $data[$field['name']] = $value->timestamp;
                                } elseif (strtotime($value)) {
                                    $data[$field['name']] = Carbon::parse($value)->timestamp;
                                } else {
                                    $data[$field['name']] = 0; // Handle unexpected formats
                                }
                            } catch (Exception $e) {
                                $data[$field['name']] = 0; // Handle invalid date formats gracefully
                            }
                        }
                        break;
                    case 'enum':
                        // Convert to value
                        $data[$field['name']] = '';
                        if (!empty($this->{$field['name']}) && !empty($this->{$field['name']}->value)) {
                            $data[$field['name']] = $this->{$field['name']}->value;
                        }
                        break;
                    case 'decimal':
                    case 'double':
                    case 'float':
                        $data[$field['name']] = (float)$this->{$field['name']};
                        break;
                    case 'smallint':
                    case 'mediumint':
                    case 'int':
                    case 'bigint':
                        $data[$field['name']] = (int)$this->{$field['name']};
                        break;
                    case 'char':
                    case 'varchar':
                    case 'text':
                    case 'mediumtext':
                    case 'longtext':
                        $data[$field['name']] = (string)$this->{$field['name']};
                        break;
                    default:
                        $data[$field['name']] = $this->{$field['name']};
                }
            } else {
                // Switch based on TypeSense type to get the right 'blank' default
                switch($field['type']) {
                    case 'bool':
                        $data[$field['name']] = false;
                        break;
                    case 'float':
                    case 'int32':
                    case 'int64':
                        $data[$field['name']] = 0;
                        break;
                    case 'geopoint':
                        $data[$field['name']] = [-90, -90];
                        break;
                    case 'string':
                        $data[$field['name']] = '';
                        break;
                    default:
                        $data[$field['name']] = null;
                }
            }
        }

        // Set specific datatypes
        $data['id'] = (string) $this->id;

        return $data;
    }
}
