<?php

namespace Neutrino\Ion3Core\Transformers;

use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Enums\Ion3DataSource;
use Neutrino\Ion3Core\Services\CWSClient;
use Neutrino\Ion3Core\Helpers\Time;

class Ion3AgentDataFromCWSTransformer extends Ion3AgentDataTransformer
{
	public static function transform(array $data): array
	{
		Log::channel(CWSClient::getLogChannel(CWSClient::$MemberEntity))->info("Transforming CWS Agent Data (MemberMlsId: {$data['MemberMlsId']} | ListingKey: {$data['MemberKey']}) from {$data['OriginatingSystemName']}" . (isset($data['MemberAOR']) ? ":{$data['MemberAOR']}" : ""));

		$transformedData = [
			'base' => [
				'ion_source' => Ion3DataSource::CWS->getKey(),
			],
			'extra' => [],
		];

		foreach($data as $key => $value) {
			switch($key) {
				case "Country":
					$transformedData['base']['country'] = $value;
					break;
				case "OriginatingSystemName":
					$transformedData['base']['originating_system_name'] = $value;
					break;
				case "MemberAOR":
					$transformedData['base']['member_aor'] = $value;
					break;
				case "MemberKey":
					$transformedData['base']['member_key'] = $value;
					break;
				case "MemberMlsId":
					$transformedData['base']['member_mls_id'] = $value;
					break;
				case "MemberFirstName":
					$transformedData['base']['member_first_name'] = $value;
					break;
				case "MemberLastName":
					$transformedData['base']['member_last_name'] = $value;
					break;
				case "MemberFullName":
					$transformedData['base']['member_full_name'] = $value;
					break;
				case "MemberEmail":
					$transformedData['base']['member_email'] = $value;
					break;
				case "MemberMobilePhone":
					$transformedData['base']['member_mobile_phone'] = $value;
					break;
				case "MemberOfficePhone":
					$transformedData['base']['member_office_phone'] = $value;
					break;
				case "MemberDirectPhone":
					$transformedData['base']['member_direct_phone'] = $value;
					break;
				case "MemberStatus":
					$transformedData['base']['member_direct_phone'] = $value;
					break;
				case "MemberMlsSecurityClass":
					$transformedData['base']['member_mls_security_class'] = $value;
					break;
				case "MemberType":
					$transformedData['base']['member_type'] = $value;
					break;
				case "OfficeKey":
					$transformedData['base']['office_key'] = $value;
					break;
				case "OfficeMlsId":
					$transformedData['base']['office_mls_id'] = $value;
					break;
				case "RawMlsModificationTimestamp":
					$transformedData['base']['modification_timestamp'] = Time::convertFromUTC0($value, (new CWSClient())->getTimezone($data['OriginatingSystemName'], isset($data['MemberAOR']) ? $data['MemberAOR'] : null)) ?  : '1969-01-01 00:00:00';;
					break;
			}

		}

		return $transformedData;
	}
}
