<?php

namespace Neutrino\Ion3Core\Transformers;

use Exception;
use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Enums\Ion3DataSource;
use Neutrino\Ion3Core\Enums\Ion3TransformerNamespace;

class Ion3DataTransformer
{
	private $dataSources;
	private $transformerNamespaces;

	public function __construct()
	{
		$this->dataSources = Ion3DataSource::asArray(true);
		$this->transformerNamespaces = Ion3TransformerNamespace::asArray();
	}

	/**
	 * @throws Exception
	 */
	public function registerDataSource(string $dataSourceShort, string $dataSourceLong = null): bool
	{
		switch(true) {
			case isset($this->dataSources[$dataSourceShort]):
				throw new Exception("Data source '{$dataSourceShort}' already exists ({$this->dataSources[$dataSourceShort]})");
			case !isset($this->dataSources[$dataSourceShort]):
				$this->dataSources[$dataSourceShort] = $dataSourceLong ?? $dataSourceShort;
				break;
		}

		return $this->isValidDataSource($dataSourceShort);
	}

	/**
	 * @throws Exception
	 */
	public function registerIon3TransformerNamespace(string $Ion3TransformerNamespace): bool
	{
		switch(true) {
			case in_array($Ion3TransformerNamespace, $this->transformerNamespaces):
				throw new Exception("Transformer Namespace '{$Ion3TransformerNamespace}' already exists...");
			case !in_array($Ion3TransformerNamespace, $this->transformerNamespaces):
				$this->transformerNamespaces[] = $Ion3TransformerNamespace;
				break;
		}

		return true;
	}

	public function getDataSources()
	{
		return $this->dataSources;
	}

	public function getTransformerNamespaces()
	{
		return $this->transformerNamespaces;
	}

	public function isValidDataSource(string $dataSourceShort) : bool
	{
		return isset($this->dataSources[$dataSourceShort]);
	}
}
