<?php

namespace Neutrino\Ion3Core\Transformers;

use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Enums\Ion3DataSource;
use Neutrino\Ion3Core\Services\CWSClient;
use Neutrino\Ion3Core\Helpers\Time;

class Ion3MediaDataFromCWSTransformer extends Ion3MediaDataTransformer
{
	public static function transform(array $data): array
	{
		Log::channel(CWSClient::getLogChannel(CWSClient::$MediaEntity))->info("Transforming CWS Media Data (MediaCategory: {$data['MediaCategory']} | MediaKey: {$data['MediaKey']} | ResourceRecordID: {$data['ResourceRecordID']} | ResourceRecordKey: {$data['ResourceRecordKey']}) from {$data['OriginatingSystemName']}");

		$transformedData = [
			'base' => [
				'ion_source' => Ion3DataSource::CWS->getKey(),
			],
			'extra' => [],
		];

		foreach($data as $key => $value) {

			switch($key) {
				case "OriginatingSystemName":
					$transformedData['base']['originating_system_name'] = $value;
					break;
				case "ResourceName":
					$transformedData['base']['resource_name'] = $value;
					break;
				case "ResourceRecordID":
					$transformedData['base']['resource_record_id'] = $value;
					break;
				case "ResourceRecordKey":
					$transformedData['base']['resource_record_key'] = $value;
					break;
				case "Permission":
					$transformedData['base']['permission'] = $value;
					break;
				case "MediaKey":
					$transformedData['base']['media_key'] = $value;
					break;
				case "MediaType":
					$transformedData['base']['media_type'] = $value;
					break;
				case "MediaCategory":
					$transformedData['base']['media_category'] = $value;
					break;
				case "MediaStatus":
					$transformedData['base']['media_status'] = $value;
					break;
				case "Order":
					$transformedData['base']['order'] = $value;
					break;
				case "PreferredPhotoYN":
					$transformedData['base']['preferred_photo_yn'] = $value;
					break;
				case "MediaURL":
					$transformedData['base']['media_url'] = $value;
					break;
				case "MediaHTML":
					$transformedData['base']['media_html'] = $value;
					break;
				case "LongDescription":
					$transformedData['base']['long_description'] = $value;
					break;
				case "ShortDescription":
					$transformedData['base']['short_description'] = $value;
					break;
				case "ImageOf":
					$transformedData['base']['image_of'] = $value;
					break;
				case "ImageWidth":
					$transformedData['base']['image_width'] = $value;
					break;
				case "ImageHeight":
					$transformedData['base']['image_height'] = $value;
					break;
				case "MediaModificationTimestamp":
					$transformedData['base']['modification_timestamp'] = Time::convertFromUTC0($value, (new CWSClient())->getTimezone($data['OriginatingSystemName']));
					break;
			}

		}

		return $transformedData;
	}
}
