<?php

namespace Neutrino\Ion3Core\Transformers;

use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Enums\Ion3DataSource;
use Neutrino\Ion3Core\Services\CWSClient;
use Neutrino\Ion3Core\Helpers\Time;

class Ion3OfficeDataFromCWSTransformer extends Ion3OfficeDataTransformer
{
	public static function transform(array $data): array
	{
		Log::channel(CWSClient::getLogChannel(CWSClient::$OfficeEntity))->info("Transforming CWS Office Data (OfficeMlsId: {$data['OfficeMlsId']} | OfficeKey: {$data['OfficeKey']}) from {$data['OriginatingSystemName']}" . (isset($data['OfficeAOR']) ? ":{$data['OfficeAOR']}" : ""));

		$transformedData = [
			'base' => [
				'ion_source' => Ion3DataSource::CWS->getKey(),
			],
			'extra' => [],
		];

		foreach($data as $key => $value) {

			switch($key) {
				case "OriginatingSystemName":
					$transformedData['base']['originating_system_name'] = $value;
					break;
				case "OfficeAOR":
					$transformedData['base']['office_aor'] = $value;
					break;
				case "OfficeKey":
					$transformedData['base']['office_key'] = $value;
					break;
				case "OfficeMlsId":
					$transformedData['base']['office_mls_id'] = $value;
					break;
				case "OfficeName":
					$transformedData['base']['office_name'] = $value;
					break;
				case "OfficeEmail":
					$transformedData['base']['office_email'] = $value;
					break;
				case "OfficePhone":
					$transformedData['base']['office_phone'] = $value;
					break;
				case "OfficeAddress1":
					$transformedData['base']['office_address_1'] = $value;
					break;
				case "OfficeAddress2":
					$transformedData['base']['office_address_2'] = $value;
					break;
				case "OfficeCity":
					$transformedData['base']['office_city'] = $value;
					break;
				case "OfficeStateOrProvince":
					$transformedData['base']['office_state_or_province'] = $value;
					break;
				case "OfficePostalCode":
					$transformedData['base']['office_postal_code'] = $value;
					break;
				case "OfficeCountry":
					$transformedData['base']['office_country'] = $value;
					break;
				case "OfficeStatus":
					$transformedData['base']['office_status'] = $value;
					break;
				case "OfficeType":
					$transformedData['base']['office_type'] = $value;
					break;
				case "RawMlsModificationTimestamp":
					$transformedData['base']['modification_timestamp'] = Time::convertFromUTC0($value, (new CWSClient())->getTimezone($data['OriginatingSystemName'], isset($data['OfficeAOR']) ? $data['OfficeAOR'] : null)) ?  : '1969-01-01 00:00:00';;
					break;
			}

		}

		return $transformedData;
	}
}
