<?php

namespace Neutrino\Ion3Core\Transformers;

use Illuminate\Support\Facades\Log;
use Neutrino\Ion3Core\Enums\Ion3DataSource;
use Neutrino\Ion3Core\Services\CWSClient;
use Neutrino\Ion3Core\Helpers\Time;

class Ion3OpenHouseDataFromCWSTransformer extends Ion3OpenHouseDataTransformer
{
	public static function transform(array $data): array
	{
		Log::channel(CWSClient::getLogChannel(CWSClient::$OpenHouseEntity))->info("Transforming CWS Open House Data (OpenHouseKey: {$data['OpenHouseKey']} | ListingId: {$data['ListingId']} | ListingKey: {$data['ListingKey']}) from {$data['OriginatingSystemName']}");

		$transformedData = [
			'base' => [
				'ion_source' => Ion3DataSource::CWS->getKey(),
			],
			'extra' => [],
		];

		foreach($data as $key => $value) {
			switch($key) {
				case "OriginatingSystemName":
					$transformedData['base']['originating_system_name'] = $value;
					break;
				case "OfficeKey":
					$transformedData['base']['office_key'] = $value;
					break;
				case "OfficeMlsId":
					$transformedData['base']['office_mls_id'] = $value;
					break;
				case "ListingKey":
					$transformedData['base']['listing_key'] = $value;
					break;
				case "ListingId":
					$transformedData['base']['reso_listing_id'] = $value;
					break;
				case "OpenHouseType":
					$transformedData['base']['open_house_type'] = $value;
					break;
				case "OpenHouseDate":
					$transformedData['base']['open_house_date'] = $value;
					break;
				case "OpenHouseStartTime":
					$transformedData['base']['open_house_start_time'] = Time::convertFromUTC0($value, (new CWSClient())->getTimezone($data['OriginatingSystemName']));
					break;
				case "OpenHouseEndTime":
					$transformedData['base']['open_house_end_time'] = Time::convertFromUTC0($value, (new CWSClient())->getTimezone($data['OriginatingSystemName']));
					break;
				case "OpenHouseRemarks":
					$transformedData['base']['open_house_remarks'] = $value;
					break;
				case "OpenHouseStatus":
					$transformedData['base']['open_house_status'] = $value;
					break;
				case "AppointmentRequiredYN":
					$transformedData['base']['appointment_required_yn'] = $value;
					break;
				case "LiveStreamOpenHouseUrl":
					$transformedData['base']['live_stream_open_house_url'] = $value;
					break;
				case "OpenHouseKey":
					$transformedData['base']['open_house_key'] = $value;
					break;
				case "ShowingAgentKey":
					$transformedData['base']['showing_agent_key'] = $value;
					break;
				case "ShowingAgentMlsId":
					$transformedData['base']['showing_agent_mls_id'] = $value;
					break;
				case "ModificationTimestamp":
					$transformedData['base']['modification_timestamp'] = Time::convertFromUTC0($value, (new CWSClient())->getTimezone($data['OriginatingSystemName']));
					break;
			}

		}

		if(!isset($transformedData['base']['open_house_date']) && isset($transformedData['base']['open_house_start_time'])) {
			$transformedData['base']['open_house_date'] = explode(" ", $transformedData['base']['open_house_start_time'])[0];
		}

		return $transformedData;
	}
}
